@@ -1,11 +1,9 @@
 def missing_openmm(*args, **kwargs):
     raise RuntimeError("Install OpenMM to use this feature")
 
-try:
-    import simtk.openmm
-    import simtk.openmm.app
-except ImportError:
-    HAS_OPENMM = False
+from openpathsampling.integration_tools import HAS_OPENMM
+
+if not HAS_OPENMM:
     Engine = missing_openmm
     empty_snapshot_from_openmm_topology = missing_openmm
     snapshot_from_pdb = missing_openmm
